setwd("~/Desktop")
dataset <- read.csv('Social_Network_Ads.csv')
dataset = dataset[3:5]
summary(dataset)
head(dataset)
dataset$Purchased = factor(dataset$Purchased, levels = c(0, 1))

library(caTools)
set.seed(123)
split = sample.split(dataset$Purchased, SplitRatio = 0.75)
training_set = subset(dataset, split == TRUE)
test_set = subset(dataset, split == FALSE)
dim(test_set)

head(training_set)
dim(training_set)
dim(test_set)

# plat the actual data 
plot(dataset[, -3],
     main = 'Dataset',
     xlab = 'Age', ylab = 'Estimated Salary') 





### Fit the Logistics regression model ###

library(tidyverse)
library(caret)
# Fit the Logit model
logit <- glm(training_set$Purchased~., data=training_set, family = binomial(link="logit"))
# Summarize the model
summary(logit)
# Make predictions
probabilities <- logit %>% predict(test_set, type = "response")
predicted.classes <- ifelse(probabilities > 0.5, 1, 0)
test.error.LR<-mean(predicted.classes != test_set$Purchased)
# Model accuracy
mean(predicted.classes == test_set$Purchased)

probabilities <- logit %>% predict(training_set, type = "response")
predicted.classes <- ifelse(probabilities > 0.5, 1, 0)
training.error.LR<-mean(predicted.classes != training_set$Purchased)

training.error.LR
test.error.LR

# plat the data 
set=training_set
plot(set[, -3],
     main = 'Logistic Regression (Training set)',
     xlab = 'Age', ylab = 'Estimated Salary') 
probabilities <- logit %>% predict(set, type = "response")
predicted.classes <- ifelse(probabilities > 0.5, 1, 0)
points(set, pch = 21, bg = ifelse(predicted.classes == 1, 'green4', 'red3'))

set = test_set
plot(set[, -3], main = 'Logistic Regression (Test set)',
     xlab = 'Age', ylab = 'Estimated Salary')
probabilities <- logit %>% predict(set, type = "response")
predicted.classes <- ifelse(probabilities > 0.5, 1, 0)
points(set, pch = 21, bg = ifelse(predicted.classes == 1, 'green4', 'red3'))



### Fit the classification tree ###

library(rpart)
library(rpart.plot)

classification.tree<-rpart(training_set$Purchased~., data=training_set)
prp(classification.tree)
y_pred.CT<-predict(classification.tree, newdata = test_set[,-3], type = "class")
table(test_set[, 3], y_pred.CT)
cm = table(test_set[, 3], y_pred.CT)
cm
accuracy.CT<-mean(y_pred.CT==test_set[,3])
1-accuracy.CT
test.error.CT<-mean(y_pred.CT!=test_set[,3])

y_pred.CT<-predict(classification.tree, newdata = training_set[,-3], type = "class")
training.error.CT<-mean(y_pred.CT != training_set$Purchased)

training.error.CT
test.error.CT


#plat the data 
set=training_set
plot(set[, -3],
     main = 'Classification Tree (Training set)',
     xlab = 'Age', ylab = 'Estimated Salary') 
points(set, pch = 21, bg = ifelse(predict(classification.tree, newdata = set[,-3], type = "class") == 1, 'green4', 'red3'))

set = test_set
plot(set[, -3], main = 'Classification Tree (Test set)',
     xlab = 'Age', ylab = 'Estimated Salary')
points(set, pch = 21, bg = ifelse(predict(classification.tree, newdata = set[,-3], type = "class") == 1, 'green4', 'red3'))




### Fit the random forest ###


library(randomForest)
classifier = randomForest(x = training_set[,-3], y = training_set$Purchased,  ntree = 500, random_state = 0)
y_pred.RF = predict(classifier, newdata = test_set[,-3])
table(test_set[, 3], y_pred.RF)
cm = table(test_set[, 3], y_pred.RF)
cm
accuracy.RF<-mean(y_pred.RF==test_set[,3])
1-accuracy.RF

test.error.RF<-mean(y_pred.RF!=test_set[,3])

y_pred.RF<-predict(classifier, newdata = training_set[,-3])
training.error.RF<-mean(y_pred.RF != training_set$Purchased)

training.error.RF
test.error.RF

# declare set as the training set
set = training_set

# plat the data 
plot(set[, -3],
     main = 'Random Forest classification (Training set)',
     xlab = 'Age', ylab = 'Estimated Salary') 
points(set, pch = 21, bg = ifelse(predict(classifier, newdata = set[,-3]) == 1, 'green4', 'red3'))

set = test_set
plot(set[, -3], main = 'Random Forest classification (Test set)',
     xlab = 'Age', ylab = 'Estimated Salary')
points(set, pch = 21, bg = ifelse(predict(classifier, newdata = set[,-3]) == 1, 'green4', 'red3'))



